#
# spec file for package python-Pympler
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-Pympler
Version:        1.0.1
Release:        4.3
Summary:        A tool to analyze the memory behavior of Python objects
License:        Apache-2.0
URL:            https://github.com/pympler/pympler
Source:         https://files.pythonhosted.org/packages/source/P/Pympler/Pympler-%{version}.tar.gz
# PATCH-FIX-UPSTREAM pympler-flaky-tests.patch gh#pympler/pympler#90 mcepl@suse.com
# More cycles needed with more recent versions of Python
Patch0:         pympler-flaky-tests.patch
BuildRequires:  %{python_module bottle}
BuildRequires:  %{python_module dbm}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
Requires:       python-tk
%python_subpackages

%description
Pympler is a development tool to measure, monitor and analyze the
memory behavior of Python objects in a running Python application.

By pympling a Python application, detailed insight in the size and
the lifetime of Python objects can be obtained.  Undesirable or
unexpected runtime behavior like memory bloat and other "pymples"
can easily be identified.

%prep
%autosetup -p1 -n Pympler-%{version}

# Remove bundled bottle (gh#pympler/pympler#148)
rm pympler/util/bottle.py

# Remove unnecessary shebang
sed -i '1{\@^#!%{_bindir}/env python@d}' pympler/asizeof.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# gh#pympler/pympler#134
skiptests="test_repr_function"
# gh#pympler/pympler#148
skiptests+=" or test_findgarbage or test_prune or test_get_tree"
%pytest -k "not ($skiptests)"

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/pympler
%{python_sitelib}/Pympler-%{version}*-info

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Oct 27 2022 Matej Cepl <mcepl@suse.com>
- Add _constraints
* Thu Oct 27 2022 Matej Cepl <mcepl@suse.com>
- Clean up SPEC file.
* Thu Oct 27 2022 Matej Cepl <mcepl@suse.com>
- Remove no-inspect-getargspec.patch, because we unbundle
  bottle.py (gh#pympler/pympler#148).
* Wed Oct 26 2022 Matej Cepl <mcepl@suse.com>
- Reorganize skipping of failing tests.
* Wed Oct 26 2022 Matej Cepl <mcepl@suse.com>
- Add no-inspect-getargspec.patch porting out deprecated
  (and in 3.11 removed) method inspect.getargspec
  (gh#pympler/pympler#148).
* Wed Jun  8 2022 Matej Cepl <mcepl@suse.com>
- Add BR for python-dbm to make build working on 15.*.
* Tue Jun  7 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to 1.0.1:
  - The resource module is only available on Unix, the mmap module
    is also available on Windows.
* Wed Dec 22 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.0:
  * Added
    + Python 3.10 support
    + Added type annotations to various Pympler modules which are checked via
    Mypy
  * Removed
    + Python 2.7 and 3.5 support
  * Fixed
    + Fix summarizing objects at higher verbosity levels -- By Colin Watson
    + Fix tree widget import for Python 3.5 and higher -- By Felix Jung (#77)
    + Fix compatibility issues with numpy 1.19 and later -- By Jean
    Brouwers (#121)
    + Fix object filtering by size in muppy -- By Kris Jurka
    + Fix documentation typos -- By Tim Gates
- Use pytest to run the test suite.
* Sat Feb 27 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v0.9
  * Added Python 3.9 support
  * Added compatibility with Django 3.x
  * Removed Python 3.4 support
  * Include size of data when sizing Numpy slices
  * Fix KeyError when sizing dicts in certain scenarios
* Mon Nov 25 2019 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.8:
  Added
  * Python 3.8 support
  * Compatibility with Django Debug Toolbar 2.x
  Removed
  * Python 3.3 support
  * Compatibility with Django Debug Toolbar 1.x
  Fixed
  * Include dicts which aren't tracked by garbage collector in summary diff
  * Fix formatting of Python 3 class names in summary diff
* Tue Aug 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix flaky tests:
  * pympler-flaky-tests.patch
* Mon Aug 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, used by attrs
